#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MOD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MOD_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/mod.hpp>

#endif
